resolvers

package
v0.0.0-...-17d044f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2020 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Resolver

type Resolver struct {
	// contains filtered or unexported fields
}

func NewResolver

func NewResolver(parser m.Parser) Resolver

Construct a new Resolver and automatically read the initialization files

func (Resolver) IsValid

func (r Resolver) IsValid(b m.BankAccount) bool

IsValid checks if a bank account number is valid

Jump to