Documentation
¶
Index ¶
- func FollowsException3(b m.BankAccount, scData m.SortCodeData) bool
- func WeightsForException2Or9(b m.BankAccount, sc m.SortCodeData) (weights []int)
- type Exception10Checker
- type Exception14Checker
- type Exception1Checker
- type Exception2Checker
- type Exception4Checker
- type Exception5Checker
- type Exception6Checker
- type Exception7Checker
- type Exception8Checker
- type Exception9Checker
- type GeneralChecker
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FollowsException3 ¶
func FollowsException3(b m.BankAccount, scData m.SortCodeData) bool
FollowsException3 checks if we follow the criteria of the exception 3
func WeightsForException2Or9 ¶
func WeightsForException2Or9(b m.BankAccount, sc m.SortCodeData) (weights []int)
WeightsForException2Or9 gets weights to use for a bank account following the exception 2 or 9.
Types ¶
type Exception10Checker ¶
type Exception10Checker struct {
}
func (Exception10Checker) Handles ¶
func (e Exception10Checker) Handles(account m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception10Checker) IsValid ¶
func (e Exception10Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception14Checker ¶
type Exception14Checker struct {
}
func (Exception14Checker) Handles ¶
func (e Exception14Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception14Checker) IsValid ¶
func (e Exception14Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception1Checker ¶
type Exception1Checker struct {
}
func (Exception1Checker) Handles ¶
func (e Exception1Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception1Checker) IsValid ¶
func (e Exception1Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception2Checker ¶
type Exception2Checker struct {
}
func (Exception2Checker) Handles ¶
func (e Exception2Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception2Checker) IsValid ¶
func (e Exception2Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception4Checker ¶
type Exception4Checker struct {
}
func (Exception4Checker) Handles ¶
func (e Exception4Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception4Checker) IsValid ¶
func (e Exception4Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception5Checker ¶
func (Exception5Checker) Handles ¶
func (e Exception5Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception5Checker) IsValid ¶
func (e Exception5Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception6Checker ¶
type Exception6Checker struct {
}
func (Exception6Checker) Handles ¶
func (e Exception6Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception6Checker) IsValid ¶
func (e Exception6Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception7Checker ¶
type Exception7Checker struct {
}
func (Exception7Checker) Handles ¶
func (e Exception7Checker) Handles(account m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception7Checker) IsValid ¶
func (e Exception7Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception8Checker ¶
type Exception8Checker struct {
}
func (Exception8Checker) Handles ¶
func (e Exception8Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception8Checker) IsValid ¶
func (e Exception8Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type Exception9Checker ¶
type Exception9Checker struct {
Weights map[string]m.SortCodeData
}
func (Exception9Checker) Handles ¶
func (e Exception9Checker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (Exception9Checker) IsValid ¶
func (e Exception9Checker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
type GeneralChecker ¶
type GeneralChecker struct {
}
func (GeneralChecker) Handles ¶
func (e GeneralChecker) Handles(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Determine if the checker is able to validate the bank account
func (GeneralChecker) IsValid ¶
func (e GeneralChecker) IsValid(b m.BankAccount, sc m.SortCodeData, attempt int) bool
Tell if the bank account is valid
func (GeneralChecker) RemainderFromRegularCheck ¶
func (e GeneralChecker) RemainderFromRegularCheck(b m.BankAccount, scData m.SortCodeData) int
RemainderFromRegularCheck gets the remainder of the check